==> webkit2gtk_2.35.1.orig.tar.xz: webkitgtk-2.35.1/Source/WebCore/platform/graphics/filters/software/FEColorMatrixSoftwareApplier.h <==
/*
 * Copyright (C) 2004, 2005, 2006, 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2004, 2005 Rob Buis <buis@kde.org>
 * Copyright (C) 2005 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2021 Apple Inc.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "FilterEffectApplier.h"

namespace WebCore {

class FEColorMatrix;

class FEColorMatrixSoftwareApplier : public FilterEffectConcreteApplier<FEColorMatrix> {
    using Base = FilterEffectConcreteApplier<FEColorMatrix>;

public:
    FEColorMatrixSoftwareApplier(FEColorMatrix&);

    bool apply(const Filter&, const FilterEffectVector& inputEffects) override;

private:
    inline void matrix(float& red, float& green, float& blue, float& alpha) const;
    inline void saturateAndHueRotate(float& red, float& green, float& blue) const;
    inline void luminance(float& red, float& green, float& blue, float& alpha) const;

#if USE(ACCELERATE)
    void applyPlatformAccelerated(PixelBuffer&) const;
#endif
    void applyPlatformUnaccelerated(PixelBuffer&) const;

    void applyPlatform(PixelBuffer&) const;

    float m_components[9];
};

} // namespace WebCore

==> webkit2gtk_2.47.2.orig.tar.xz: webkitgtk-2.47.2/Source/WebCore/platform/graphics/filters/software/FEColorMatrixSoftwareApplier.h <==
/*
 * Copyright (C) 2004, 2005, 2006, 2007 Nikolas Zimmermann <zimmermann@kde.org>
 * Copyright (C) 2004, 2005 Rob Buis <buis@kde.org>
 * Copyright (C) 2005 Eric Seidel <eric@webkit.org>
 * Copyright (C) 2021-2022 Apple Inc.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "FilterEffectApplier.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class FEColorMatrix;
class PixelBuffer;

class FEColorMatrixSoftwareApplier final : public FilterEffectConcreteApplier<FEColorMatrix> {
    WTF_MAKE_TZONE_ALLOCATED(FEColorMatrixSoftwareApplier);
    using Base = FilterEffectConcreteApplier<FEColorMatrix>;

public:
    FEColorMatrixSoftwareApplier(const FEColorMatrix&);

private:
    bool apply(const Filter&, const FilterImageVector& inputs, FilterImage& result) const final;

    inline void matrix(float& red, float& green, float& blue, float& alpha) const;
    inline void saturateAndHueRotate(float& red, float& green, float& blue) const;
    inline void luminance(float& red, float& green, float& blue, float& alpha) const;

#if USE(ACCELERATE)
    void applyPlatformAccelerated(PixelBuffer&) const;
#endif
    void applyPlatformUnaccelerated(PixelBuffer&) const;

    void applyPlatform(PixelBuffer&) const;

    float m_components[9];
};

} // namespace WebCore
